@@ -1,23 +1,11 @@
 /*
     Gettext translation file analyzer
 
-    Copyright (C) 2007 Montel Laurent <montel@kde.org>
-    Copyright (C) 2009 Jos van den Oever <jos@vandenoever.info>
-    Copyright (C) 2014 Nick Shaforostoff <shaforostoff@gmail.com>
+    SPDX-FileCopyrightText: 2007 Montel Laurent <montel@kde.org>
+    SPDX-FileCopyrightText: 2009 Jos van den Oever <jos@vandenoever.info>
+    SPDX-FileCopyrightText: 2014 Nick Shaforostoff <shaforostoff@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 
@@ -33,9 +21,13 @@ POExtractor::POExtractor(QObject* parent)
 
 }
 
+const QStringList supportedMimeTypes = {
+    QStringLiteral("text/x-gettext-translation"),
+};
+
 QStringList POExtractor::mimetypes() const
 {
-    return QStringList() << QStringLiteral("text/x-gettext-translation");
+    return supportedMimeTypes;
 }
 
 void POExtractor::endMessage()
@@ -59,9 +51,13 @@ void POExtractor::handleComment(const char* data, quint32 length)
 
 void POExtractor::handleLine(const char* data, quint32 length)
 {
-    if (state == ERROR) return;
+    if (state == ERROR) {
+        return;
+    }
     if (state == WHITESPACE) {
-        if (length == 0) return;
+        if (length == 0) {
+            return;
+        }
         if (data[0] != '#') {
             state = COMMENT; //this allows PO files w/o comments
         } else {
@@ -177,3 +173,5 @@ void POExtractor::extract(ExtractionResult* result)
     result->add(Property::LineCount, lines);
     //TODO WordCount
 }
+
+#include "moc_poextractor.cpp"
